.. :changelog:

Changelog
=========

1.1.4 (2013-08-29)
------------------

- Test case improvements
- `Coveralls.io <http://coveralls.io/>`_ support

1.1.3 (2013-07-24)
------------------

- Python 3.3 compatibility

1.1.0 (2013-05-15)
------------------

- Support for `DynDNS Update API <http://dyn.com/support/developers/api/>`_ 
- DDNS auth info storage changed

1.0.1 (2013-05-10)
------------------

- Added flexibility to DNS updater with ``abc.ABCMeta``
- Code organization
- Manual settings file removed (auth info can be stored via command line)

0.1.0 (2013-03-22)
------------------

- Conception
